@@ -1,10 +1,7 @@
 
 package XML::SRS;
 
-our $VERSION = "0.06_01";
-
-BEGIN { our $PROTOCOL_VERSION = "5.0" };
-use XML::SRS::Version;
+our $VERSION = "0.01";
 
 use Moose::Role;
 use XML::SRS::Types;
@@ -33,25 +30,15 @@ use XML::SRS::Audit;
 use XML::SRS::Whois;
 use XML::SRS::ACL::Query;
 use XML::SRS::Registrar::Query;
-use XML::SRS::Registrar::Update;
 use XML::SRS::Domain::Create;
 use XML::SRS::Domain::Update;
 use XML::SRS::Domain::Query;
-use XML::SRS::Domain::Transferred;
 use XML::SRS::UDAIValid::Query;
-use XML::SRS::Handle::Create;
-use XML::SRS::Handle::Update;
-use XML::SRS::Handle::Query;
-use XML::SRS::Message;
-use XML::SRS::Message::Ack::Response;
-use XML::SRS::GetMessages;
-use XML::SRS::AckMessage;
 
 # ActionResponse types:
 use XML::SRS::Error;
 use XML::SRS::ACL;
 use XML::SRS::Domain;
-use XML::SRS::Handle;
 use XML::SRS::Registrar;
 use XML::SRS::UDAIValid;
 
@@ -66,18 +53,17 @@ XML::SRS - Shared Registry System XML Protocol
 =head1 SYNOPSIS
 
  my $create = XML::SRS::Domain::Create->new(
-          action_id => "kaihoro.co.nz-create-".time(),
-          domain_name => "kaihoro.co.nz",
+          domain_name => "thinkbig.co.nz",
           term => 12,
           delegate => 1,
           contact_registrant => {
-               name => "Lord Crumb",
-               email => 'kaihoro.takeaways@gmail.com',
+               name => "Robert Muldoon",
+               email => 'get.drunk.and.call.a.snap.election@gmail.com',
                address => {
                     address1 => "57 Mount Pleasant St",
                     address2 => "Burbia",
-                    city => "Kaihoro",
-                    region => "Nelson",
+                    city => "Ohai",
+                    region => "Southland",
                     cc => "NZ",
                },
                phone => {
@@ -101,34 +87,10 @@ updates), which was developed using XML Schema and XML Namespaces.  As
 such, the SRS protocol as a stable standard far pre-dates EPP, which
 took a further 2 years to reach 1.0 status.
 
-=head2 WARNING: SITE^WMODULE UNDER CONSTRUCTION
-
-The classes which are present, while enough to be able to parse the
-protocol specification, are not fixed in API terms until they are
-documented and tested.  Please consider any attribute which is not yet
-at least documented to be under review and subject to rename.  This is
-thought to lead to a clearer implementation than fixing attribute
-names to the somewhat random (though well-known) names used in the
-XML.  Use of C<sub BUILDARGS { }> to allow either may be considered;
-patches welcome.
-
-Similarly with undocumented portions of the implementation.  If you
-would like to make sure that the code you write against it doesn't
-need rewriting, please send a patch/pull request!
-
 This module currently implements the XML part of the protocol only;
 converting this into the HTTPS POST, with PGP signature, is still
 TO-DO.
 
-=head1 GLOBALS
-
-There is currently a C<$XML::SRS::PROTOCOL_VERSION> variable which
-includes the version of the SRS protocol parsed by the module.
-Currently, the ability to parse more than one version at a time is not
-supported, so in the event of registry protocol version changes, you
-will need to upgrade the version of L<XML::SRS> in lock-step for any
-new functionality.  This global is not exported.
-
 =head1 SOURCE, SUBMISSIONS, SUPPORT
 
 Source code is available from Catalyst:
